@@ -1,8 +1,7 @@
+use fast_image_resize::pixels::U8x4;
 use resize::Pixel::RGBA8P;
 use rgb::FromSlice;
-
-use fast_image_resize::pixels::U8x4;
-use testing::PixelTestingExt;
+use utils::testing::PixelTestingExt;
 
 mod utils;
 
