@@ -12,3 +12,8 @@ pub use self::rational::*;
 
 mod pixfmt;
 pub use self::pixfmt::*;
+
+#[cfg(feature = "ffmpeg_8_0")]
+mod profile;
+#[cfg(feature = "ffmpeg_8_0")]
+pub use self::profile::*;
