@@ -13,11 +13,12 @@
 //!
 //! [`ImageError`]: enum.ImageError.html
 
+use std::collections::TryReserveError;
 use std::error::Error;
 use std::{fmt, io};
 
 use crate::color::ExtendedColorType;
-use crate::image::ImageFormat;
+use crate::{metadata::Cicp, ImageFormat};
 
 /// The generic error type for image operations.
 ///
@@ -81,6 +82,10 @@ pub struct UnsupportedError {
 pub enum UnsupportedErrorKind {
     /// The required color type can not be handled.
     Color(ExtendedColorType),
+    /// Dealing with an intricate layout is not implemented for an algorithm.
+    ColorLayout(ExtendedColorType),
+    /// The colors or transfer function of the CICP are not supported.
+    ColorspaceCicp(Cicp),
     /// An image format is not supported.
     Format(ImageFormatHint),
     /// Some feature specified by string.
@@ -120,11 +125,20 @@ pub enum ParameterErrorKind {
     DimensionMismatch,
     /// Repeated an operation for which error that could not be cloned was emitted already.
     FailedAlready,
+    /// The cicp is required to be RGB-like but had other matrix transforms or narrow range.
+    RgbCicpRequired(Cicp),
     /// A string describing the parameter.
     /// This is discouraged and is likely to get deprecated (but not removed).
     Generic(String),
     /// The end of the image has been reached.
     NoMoreData,
+    /// An operation expected a concrete color space but another was found.
+    CicpMismatch {
+        /// The cicp that was expected.
+        expected: Cicp,
+        /// The cicp that was found.
+        found: Cicp,
+    },
 }
 
 /// An error was encountered while decoding an image.
@@ -166,9 +180,9 @@ pub enum LimitErrorKind {
     /// The specified strict limits are not supported for this operation
     Unsupported {
         /// The given limits
-        limits: crate::io::Limits,
+        limits: crate::Limits,
         /// The supported strict limits
-        supported: crate::io::LimitSupport,
+        supported: crate::LimitSupport,
     },
 }
 
@@ -194,16 +208,19 @@ impl UnsupportedError {
     ///
     /// If the operation was not connected to a particular image format then the hint may be
     /// `Unknown`.
+    #[must_use]
     pub fn from_format_and_kind(format: ImageFormatHint, kind: UnsupportedErrorKind) -> Self {
         UnsupportedError { format, kind }
     }
 
     /// Returns the corresponding `UnsupportedErrorKind` of the error.
+    #[must_use]
     pub fn kind(&self) -> UnsupportedErrorKind {
         self.kind.clone()
     }
 
     /// Returns the image format associated with this error.
+    #[must_use]
     pub fn format_hint(&self) -> ImageFormatHint {
         self.format.clone()
     }
@@ -221,6 +238,7 @@ impl DecodingError {
     /// Create a `DecodingError` for an image format.
     ///
     /// The error will not contain any further information but is very easy to create.
+    #[must_use]
     pub fn from_format_hint(format: ImageFormatHint) -> Self {
         DecodingError {
             format,
@@ -229,6 +247,7 @@ impl DecodingError {
     }
 
     /// Returns the image format associated with this error.
+    #[must_use]
     pub fn format_hint(&self) -> ImageFormatHint {
         self.format.clone()
     }
@@ -246,6 +265,7 @@ impl EncodingError {
     /// Create an `EncodingError` for an image format.
     ///
     /// The error will not contain any further information but is very easy to create.
+    #[must_use]
     pub fn from_format_hint(format: ImageFormatHint) -> Self {
         EncodingError {
             format,
@@ -254,6 +274,7 @@ impl EncodingError {
     }
 
     /// Return the image format associated with this error.
+    #[must_use]
     pub fn format_hint(&self) -> ImageFormatHint {
         self.format.clone()
     }
@@ -261,6 +282,7 @@ impl EncodingError {
 
 impl ParameterError {
     /// Construct a `ParameterError` directly from a corresponding kind.
+    #[must_use]
     pub fn from_kind(kind: ParameterErrorKind) -> Self {
         ParameterError {
             kind,
@@ -269,6 +291,7 @@ impl ParameterError {
     }
 
     /// Returns the corresponding `ParameterErrorKind` of the error.
+    #[must_use]
     pub fn kind(&self) -> ParameterErrorKind {
         self.kind.clone()
     }
@@ -276,22 +299,36 @@ impl ParameterError {
 
 impl LimitError {
     /// Construct a generic `LimitError` directly from a corresponding kind.
+    #[must_use]
     pub fn from_kind(kind: LimitErrorKind) -> Self {
         LimitError { kind }
     }
 
     /// Returns the corresponding `LimitErrorKind` of the error.
+    #[must_use]
     pub fn kind(&self) -> LimitErrorKind {
         self.kind.clone()
     }
 }
 
+impl From<LimitErrorKind> for LimitError {
+    fn from(kind: LimitErrorKind) -> Self {
+        Self { kind }
+    }
+}
+
 impl From<io::Error> for ImageError {
     fn from(err: io::Error) -> ImageError {
         ImageError::IoError(err)
     }
 }
 
+impl From<TryReserveError> for ImageError {
+    fn from(_: TryReserveError) -> ImageError {
+        ImageError::Limits(LimitErrorKind::InsufficientMemory.into())
+    }
+}
+
 impl From<ImageFormat> for ImageFormatHint {
     fn from(format: ImageFormat) -> Self {
         ImageFormatHint::Exact(format)
@@ -353,27 +390,32 @@ impl fmt::Display for UnsupportedError {
             }
             UnsupportedErrorKind::Format(format @ ImageFormatHint::PathExtension(_)) => write!(
                 fmt,
-                "The file extension {} was not recognized as an image format",
-                format,
+                "The file extension {format} was not recognized as an image format",
             ),
             UnsupportedErrorKind::Format(format) => {
-                write!(fmt, "The image format {} is not supported", format,)
+                write!(fmt, "The image format {format} is not supported",)
             }
             UnsupportedErrorKind::Color(color) => write!(
                 fmt,
-                "The decoder for {} does not support the color type `{:?}`",
+                "The encoder or decoder for {} does not support the color type `{:?}`",
                 self.format, color,
             ),
+            UnsupportedErrorKind::ColorLayout(layout) => write!(
+                fmt,
+                "Converting with the texel memory layout {layout:?} is not supported",
+            ),
+            UnsupportedErrorKind::ColorspaceCicp(color) => write!(
+                fmt,
+                "The colorimetric interpretation of a CICP color space is not supported for `{color:?}`",
+            ),
             UnsupportedErrorKind::GenericFeature(message) => match &self.format {
                 ImageFormatHint::Unknown => write!(
                     fmt,
-                    "The decoder does not support the format feature {}",
-                    message,
+                    "The decoder does not support the format feature {message}",
                 ),
                 other => write!(
                     fmt,
-                    "The decoder for {} does not support the format features {}",
-                    other, message,
+                    "The decoder for {other} does not support the format features {message}",
                 ),
             },
         }
@@ -394,14 +436,24 @@ impl fmt::Display for ParameterError {
                 fmt,
                 "The end the image stream has been reached due to a previous error"
             ),
+            ParameterErrorKind::RgbCicpRequired(cicp) => {
+                write!(fmt, "The CICP {cicp:?} can not be used for RGB images",)
+            }
+
             ParameterErrorKind::Generic(message) => {
-                write!(fmt, "The parameter is malformed: {}", message,)
+                write!(fmt, "The parameter is malformed: {message}",)
             }
             ParameterErrorKind::NoMoreData => write!(fmt, "The end of the image has been reached",),
+            ParameterErrorKind::CicpMismatch { expected, found } => {
+                write!(
+                    fmt,
+                    "The color space {found:?} does not match the expected {expected:?}",
+                )
+            }
         }?;
 
         if let Some(underlying) = &self.underlying {
-            write!(fmt, "\n{}", underlying)?;
+            write!(fmt, "\n{underlying}")?;
         }
 
         Ok(())
@@ -480,22 +532,58 @@ impl Error for LimitError {}
 impl fmt::Display for ImageFormatHint {
     fn fmt(&self, fmt: &mut fmt::Formatter) -> Result<(), fmt::Error> {
         match self {
-            ImageFormatHint::Exact(format) => write!(fmt, "{:?}", format),
-            ImageFormatHint::Name(name) => write!(fmt, "`{}`", name),
-            ImageFormatHint::PathExtension(ext) => write!(fmt, "`.{:?}`", ext),
+            ImageFormatHint::Exact(format) => write!(fmt, "{format:?}"),
+            ImageFormatHint::Name(name) => write!(fmt, "`{name}`"),
+            ImageFormatHint::PathExtension(ext) => write!(fmt, "`.{ext:?}`"),
             ImageFormatHint::Unknown => write!(fmt, "`Unknown`"),
         }
     }
 }
 
+/// Converting [`ExtendedColorType`] to [`ColorType`][`crate::ColorType`] failed.
+///
+/// This type is convertible to [`ImageError`] as [`ImageError::Unsupported`].
+#[derive(Clone)]
+#[allow(missing_copy_implementations)]
+pub struct TryFromExtendedColorError {
+    pub(crate) was: ExtendedColorType,
+}
+
+impl fmt::Debug for TryFromExtendedColorError {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "{}", self)
+    }
+}
+
+impl fmt::Display for TryFromExtendedColorError {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(
+            f,
+            "The pixel layout {:?} is not supported as a buffer ColorType",
+            self.was
+        )
+    }
+}
+
+impl Error for TryFromExtendedColorError {}
+
+impl From<TryFromExtendedColorError> for ImageError {
+    fn from(err: TryFromExtendedColorError) -> ImageError {
+        ImageError::Unsupported(UnsupportedError::from_format_and_kind(
+            ImageFormatHint::Unknown,
+            UnsupportedErrorKind::Color(err.was),
+        ))
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
-    use std::mem;
+    use std::mem::size_of;
 
     #[allow(dead_code)]
     // This will fail to compile if the size of this type is large.
-    const ASSERT_SMALLISH: usize = [0][(mem::size_of::<ImageError>() >= 200) as usize];
+    const ASSERT_SMALLISH: usize = [0][(size_of::<ImageError>() >= 200) as usize];
 
     #[test]
     fn test_send_sync_stability() {
