@@ -8,26 +8,14 @@ pub mod bgsegm {
 
 	pub const LSBP_CAMERA_MOTION_COMPENSATION_LK: i32 = 1;
 	pub const LSBP_CAMERA_MOTION_COMPENSATION_NONE: i32 = 0;
-	#[repr(C)]
+	#[repr(i32)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 	pub enum LSBPCameraMotionCompensation {
 		LSBP_CAMERA_MOTION_COMPENSATION_NONE = 0,
 		LSBP_CAMERA_MOTION_COMPENSATION_LK = 1,
 	}
 
-	impl TryFrom<i32> for LSBPCameraMotionCompensation {
-		type Error = crate::Error;
-
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				0 => Ok(Self::LSBP_CAMERA_MOTION_COMPENSATION_NONE),
-				1 => Ok(Self::LSBP_CAMERA_MOTION_COMPENSATION_LK),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::bgsegm::LSBPCameraMotionCompensation"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::bgsegm::LSBPCameraMotionCompensation }
+	opencv_type_enum! { crate::bgsegm::LSBPCameraMotionCompensation { LSBP_CAMERA_MOTION_COMPENSATION_NONE, LSBP_CAMERA_MOTION_COMPENSATION_LK } }
 
 	/// Creates a CNT Background Subtractor
 	///
