@@ -104,7 +104,7 @@ pub mod flann {
 	/// how long to keep an object is made at the time of allocation, and there
 	/// is no need to track down all the objects to free them.
 	pub const WORDSIZE: u32 = 16;
-	#[repr(C)]
+	#[repr(i32)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 	pub enum FlannIndexType {
 		FLANN_INDEX_TYPE_8U = 0,
@@ -121,31 +121,9 @@ pub mod flann {
 		// LAST_VALUE_FLANN_INDEX_TYPE = 9,
 	}
 
-	impl TryFrom<i32> for FlannIndexType {
-		type Error = crate::Error;
+	opencv_type_enum! { crate::flann::FlannIndexType { FLANN_INDEX_TYPE_8U, FLANN_INDEX_TYPE_8S, FLANN_INDEX_TYPE_16U, FLANN_INDEX_TYPE_16S, FLANN_INDEX_TYPE_32S, FLANN_INDEX_TYPE_32F, FLANN_INDEX_TYPE_64F, FLANN_INDEX_TYPE_STRING, FLANN_INDEX_TYPE_BOOL, FLANN_INDEX_TYPE_ALGORITHM } }
 
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				0 => Ok(Self::FLANN_INDEX_TYPE_8U),
-				1 => Ok(Self::FLANN_INDEX_TYPE_8S),
-				2 => Ok(Self::FLANN_INDEX_TYPE_16U),
-				3 => Ok(Self::FLANN_INDEX_TYPE_16S),
-				4 => Ok(Self::FLANN_INDEX_TYPE_32S),
-				5 => Ok(Self::FLANN_INDEX_TYPE_32F),
-				6 => Ok(Self::FLANN_INDEX_TYPE_64F),
-				7 => Ok(Self::FLANN_INDEX_TYPE_STRING),
-				8 => Ok(Self::FLANN_INDEX_TYPE_BOOL),
-				9 => Ok(Self::FLANN_INDEX_TYPE_ALGORITHM),
-				// Duplicate of FLANN_INDEX_TYPE_ALGORITHM
-				// 9 => Ok(Self::LAST_VALUE_FLANN_INDEX_TYPE),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::flann::FlannIndexType"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::flann::FlannIndexType }
-
-	#[repr(C)]
+	#[repr(i32)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 	pub enum flann_algorithm_t {
 		FLANN_INDEX_LINEAR = 0,
@@ -173,42 +151,9 @@ pub mod flann {
 		// AUTOTUNED = 255,
 	}
 
-	impl TryFrom<i32> for flann_algorithm_t {
-		type Error = crate::Error;
+	opencv_type_enum! { crate::flann::flann_algorithm_t { FLANN_INDEX_LINEAR, FLANN_INDEX_KDTREE, FLANN_INDEX_KMEANS, FLANN_INDEX_COMPOSITE, FLANN_INDEX_KDTREE_SINGLE, FLANN_INDEX_HIERARCHICAL, FLANN_INDEX_LSH, FLANN_INDEX_SAVED, FLANN_INDEX_AUTOTUNED } }
 
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				0 => Ok(Self::FLANN_INDEX_LINEAR),
-				1 => Ok(Self::FLANN_INDEX_KDTREE),
-				2 => Ok(Self::FLANN_INDEX_KMEANS),
-				3 => Ok(Self::FLANN_INDEX_COMPOSITE),
-				4 => Ok(Self::FLANN_INDEX_KDTREE_SINGLE),
-				5 => Ok(Self::FLANN_INDEX_HIERARCHICAL),
-				6 => Ok(Self::FLANN_INDEX_LSH),
-				254 => Ok(Self::FLANN_INDEX_SAVED),
-				255 => Ok(Self::FLANN_INDEX_AUTOTUNED),
-				// Duplicate of FLANN_INDEX_LINEAR
-				// 0 => Ok(Self::LINEAR),
-				// Duplicate of FLANN_INDEX_KDTREE
-				// 1 => Ok(Self::KDTREE),
-				// Duplicate of FLANN_INDEX_KMEANS
-				// 2 => Ok(Self::KMEANS),
-				// Duplicate of FLANN_INDEX_COMPOSITE
-				// 3 => Ok(Self::COMPOSITE),
-				// Duplicate of FLANN_INDEX_KDTREE_SINGLE
-				// 4 => Ok(Self::KDTREE_SINGLE),
-				// Duplicate of FLANN_INDEX_SAVED
-				// 254 => Ok(Self::SAVED),
-				// Duplicate of FLANN_INDEX_AUTOTUNED
-				// 255 => Ok(Self::AUTOTUNED),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::flann::flann_algorithm_t"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::flann::flann_algorithm_t }
-
-	#[repr(C)]
+	#[repr(i32)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 	pub enum flann_centers_init_t {
 		FLANN_CENTERS_RANDOM = 0,
@@ -223,29 +168,9 @@ pub mod flann {
 		// CENTERS_KMEANSPP = 2,
 	}
 
-	impl TryFrom<i32> for flann_centers_init_t {
-		type Error = crate::Error;
+	opencv_type_enum! { crate::flann::flann_centers_init_t { FLANN_CENTERS_RANDOM, FLANN_CENTERS_GONZALES, FLANN_CENTERS_KMEANSPP, FLANN_CENTERS_GROUPWISE } }
 
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				0 => Ok(Self::FLANN_CENTERS_RANDOM),
-				1 => Ok(Self::FLANN_CENTERS_GONZALES),
-				2 => Ok(Self::FLANN_CENTERS_KMEANSPP),
-				3 => Ok(Self::FLANN_CENTERS_GROUPWISE),
-				// Duplicate of FLANN_CENTERS_RANDOM
-				// 0 => Ok(Self::CENTERS_RANDOM),
-				// Duplicate of FLANN_CENTERS_GONZALES
-				// 1 => Ok(Self::CENTERS_GONZALES),
-				// Duplicate of FLANN_CENTERS_KMEANSPP
-				// 2 => Ok(Self::CENTERS_KMEANSPP),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::flann::flann_centers_init_t"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::flann::flann_centers_init_t }
-
-	#[repr(C)]
+	#[repr(i32)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 	pub enum flann_datatype_t {
 		FLANN_INT8 = 0,
@@ -260,29 +185,9 @@ pub mod flann {
 		FLANN_FLOAT64 = 9,
 	}
 
-	impl TryFrom<i32> for flann_datatype_t {
-		type Error = crate::Error;
+	opencv_type_enum! { crate::flann::flann_datatype_t { FLANN_INT8, FLANN_INT16, FLANN_INT32, FLANN_INT64, FLANN_UINT8, FLANN_UINT16, FLANN_UINT32, FLANN_UINT64, FLANN_FLOAT32, FLANN_FLOAT64 } }
 
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				0 => Ok(Self::FLANN_INT8),
-				1 => Ok(Self::FLANN_INT16),
-				2 => Ok(Self::FLANN_INT32),
-				3 => Ok(Self::FLANN_INT64),
-				4 => Ok(Self::FLANN_UINT8),
-				5 => Ok(Self::FLANN_UINT16),
-				6 => Ok(Self::FLANN_UINT32),
-				7 => Ok(Self::FLANN_UINT64),
-				8 => Ok(Self::FLANN_FLOAT32),
-				9 => Ok(Self::FLANN_FLOAT64),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::flann::flann_datatype_t"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::flann::flann_datatype_t }
-
-	#[repr(C)]
+	#[repr(i32)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 	pub enum flann_distance_t {
 		FLANN_DIST_EUCLIDEAN = 1,
@@ -323,55 +228,9 @@ pub mod flann {
 		// KULLBACK_LEIBLER = 8,
 	}
 
-	impl TryFrom<i32> for flann_distance_t {
-		type Error = crate::Error;
+	opencv_type_enum! { crate::flann::flann_distance_t { FLANN_DIST_EUCLIDEAN, FLANN_DIST_MANHATTAN, FLANN_DIST_MINKOWSKI, FLANN_DIST_MAX, FLANN_DIST_HIST_INTERSECT, FLANN_DIST_HELLINGER, FLANN_DIST_CHI_SQUARE, FLANN_DIST_KULLBACK_LEIBLER, FLANN_DIST_HAMMING, FLANN_DIST_DNAMMING } }
 
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				1 => Ok(Self::FLANN_DIST_EUCLIDEAN),
-				// Duplicate of FLANN_DIST_EUCLIDEAN
-				// 1 => Ok(Self::FLANN_DIST_L2),
-				2 => Ok(Self::FLANN_DIST_MANHATTAN),
-				// Duplicate of FLANN_DIST_MANHATTAN
-				// 2 => Ok(Self::FLANN_DIST_L1),
-				3 => Ok(Self::FLANN_DIST_MINKOWSKI),
-				4 => Ok(Self::FLANN_DIST_MAX),
-				5 => Ok(Self::FLANN_DIST_HIST_INTERSECT),
-				6 => Ok(Self::FLANN_DIST_HELLINGER),
-				7 => Ok(Self::FLANN_DIST_CHI_SQUARE),
-				// Duplicate of FLANN_DIST_CHI_SQUARE
-				// 7 => Ok(Self::FLANN_DIST_CS),
-				8 => Ok(Self::FLANN_DIST_KULLBACK_LEIBLER),
-				// Duplicate of FLANN_DIST_KULLBACK_LEIBLER
-				// 8 => Ok(Self::FLANN_DIST_KL),
-				9 => Ok(Self::FLANN_DIST_HAMMING),
-				10 => Ok(Self::FLANN_DIST_DNAMMING),
-				// Duplicate of FLANN_DIST_L2
-				// 1 => Ok(Self::EUCLIDEAN),
-				// Duplicate of FLANN_DIST_L1
-				// 2 => Ok(Self::MANHATTAN),
-				// Duplicate of FLANN_DIST_MINKOWSKI
-				// 3 => Ok(Self::MINKOWSKI),
-				// Duplicate of FLANN_DIST_MAX
-				// 4 => Ok(Self::MAX_DIST),
-				// Duplicate of FLANN_DIST_HIST_INTERSECT
-				// 5 => Ok(Self::HIST_INTERSECT),
-				// Duplicate of FLANN_DIST_HELLINGER
-				// 6 => Ok(Self::HELLINGER),
-				// Duplicate of FLANN_DIST_CS
-				// 7 => Ok(Self::CS),
-				// Duplicate of FLANN_DIST_KL
-				// 8 => Ok(Self::KL),
-				// Duplicate of KL
-				// 8 => Ok(Self::KULLBACK_LEIBLER),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::flann::flann_distance_t"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::flann::flann_distance_t }
-
-	#[repr(C)]
+	#[repr(i32)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 	pub enum flann_log_level_t {
 		FLANN_LOG_NONE = 0,
@@ -381,22 +240,7 @@ pub mod flann {
 		FLANN_LOG_INFO = 4,
 	}
 
-	impl TryFrom<i32> for flann_log_level_t {
-		type Error = crate::Error;
-
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				0 => Ok(Self::FLANN_LOG_NONE),
-				1 => Ok(Self::FLANN_LOG_FATAL),
-				2 => Ok(Self::FLANN_LOG_ERROR),
-				3 => Ok(Self::FLANN_LOG_WARN),
-				4 => Ok(Self::FLANN_LOG_INFO),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::flann::flann_log_level_t"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::flann::flann_log_level_t }
+	opencv_type_enum! { crate::flann::flann_log_level_t { FLANN_LOG_NONE, FLANN_LOG_FATAL, FLANN_LOG_ERROR, FLANN_LOG_WARN, FLANN_LOG_INFO } }
 
 	/// A bucket in an LSH table
 	pub type Bucket = core::Vector<crate::flann::FeatureIndex>;
