@@ -3,16 +3,15 @@ use std::borrow::Cow::{Borrowed, Owned};
 use std::fmt;
 use std::ops::ControlFlow;
 use std::rc::Rc;
+use std::sync::LazyLock;
 
 use clang::{Availability, Entity, EntityKind, ExceptionSpecification};
 pub use desc::{FuncCppBody, FuncDesc, FuncRustBody, FuncRustExtern};
 pub use func_matcher::{FuncMatchProperties, FuncMatcher, Pred, UsageTracker};
 pub use kind::{FuncKind, OperatorKind, ReturnKind};
-use once_cell::sync::Lazy;
 use regex::bytes::Regex;
 use slice_arg_finder::SliceArgFinder;
 
-use crate::comment::strip_doxygen_comment_markers;
 use crate::debug::{DefinitionLocation, LocationName};
 use crate::element::ExcludeKind;
 use crate::entity::ToEntity;
@@ -230,7 +229,7 @@ impl<'tu, 'ge> Func<'tu, 'ge> {
 				desc.cpp_name = ancestor.cpp_name(CppNameStyle::Reference).into();
 			}
 			if config.doc_comment {
-				desc.doc_comment = ancestor.doc_comment_overloaded().into();
+				desc.doc_comment = ancestor.doc_comment().into();
 			}
 			if config.arguments {
 				desc.arguments = ancestor.arguments().into();
@@ -271,7 +270,7 @@ impl<'tu, 'ge> Func<'tu, 'ge> {
 		}
 	}
 
-	pub fn kind(&self) -> Cow<FuncKind<'tu, 'ge>> {
+	pub fn kind(&self) -> Cow<'_, FuncKind<'tu, 'ge>> {
 		match self {
 			&Self::Clang { entity, gen_env, .. } => {
 				const OPERATOR: &str = "operator";
@@ -350,39 +349,6 @@ impl<'tu, 'ge> Func<'tu, 'ge> {
 		}
 	}
 
-	/// Like [Self::doc_comment], but processes `@overload` and `@copybrief` directives if possible by copying the corresponding
-	/// doccomment
-	pub fn doc_comment_overloaded(&self) -> Cow<str> {
-		let mut out = self.doc_comment();
-		match self {
-			Func::Clang { gen_env, .. } => {
-				let line = self.file_line_name().location.as_file().map_or(0, |(_, line)| line);
-				const OVERLOAD: &str = "@overload";
-				if let Some(idx) = out.find(OVERLOAD) {
-					let rep = if let Some(copy) = gen_env.get_func_comment(line, self.cpp_name(CppNameStyle::Reference).as_ref()) {
-						Owned(format!("{copy}\n\n## Overloaded parameters\n"))
-					} else {
-						"This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.".into()
-					};
-					out.to_mut().replace_range(idx..idx + OVERLOAD.len(), &rep);
-				}
-				static COPY_BRIEF: Lazy<Regex> = Lazy::new(|| Regex::new(r"@copybrief\s+(\w+)").unwrap());
-				out.to_mut().replace_in_place_regex_cb(&COPY_BRIEF, |comment, caps| {
-					let copy_name = caps.get(1).map(|(s, e)| &comment[s..e]).expect("Impossible");
-					let mut copy_full_name = self.cpp_namespace().into_owned();
-					copy_full_name.extend_sep("::", copy_name);
-					if let Some(copy) = gen_env.get_func_comment(line, &copy_full_name) {
-						Some(copy.into())
-					} else {
-						Some("".into())
-					}
-				});
-			}
-			Func::Desc(_) => {}
-		}
-		out
-	}
-
 	pub fn return_kind(&self) -> ReturnKind {
 		match self {
 			Self::Clang { entity, gen_env, .. } => {
@@ -443,7 +409,7 @@ impl<'tu, 'ge> Func<'tu, 'ge> {
 		}
 	}
 
-	pub fn return_type_ref(&self) -> Cow<TypeRef<'tu, 'ge>> {
+	pub fn return_type_ref(&self) -> Cow<'_, TypeRef<'tu, 'ge>> {
 		match self {
 			&Self::Clang { entity, gen_env, .. } => {
 				let mut out = match self.kind().as_ref() {
@@ -515,7 +481,7 @@ impl<'tu, 'ge> Func<'tu, 'ge> {
 		}
 	}
 
-	pub fn arguments(&self) -> Cow<[Field<'tu, 'ge>]> {
+	pub fn arguments(&self) -> Cow<'_, [Field<'tu, 'ge>]> {
 		match self {
 			&Self::Clang { entity, gen_env, .. } => {
 				let arg_overrides = gen_env.settings.arg_override.get(&mut self.matcher());
@@ -603,7 +569,7 @@ impl<'tu, 'ge> Func<'tu, 'ge> {
 		out
 	}
 
-	pub fn matcher(&self) -> FuncMatchProperties {
+	pub fn matcher(&self) -> FuncMatchProperties<'_> {
 		FuncMatchProperties::new(self, self.cpp_name(CppNameStyle::Reference))
 	}
 
@@ -689,14 +655,35 @@ impl Element for Func<'_, '_> {
 		}
 	}
 
-	fn doc_comment(&self) -> Cow<str> {
+	fn doc_comment(&self) -> Cow<'_, str> {
 		match self {
-			&Self::Clang { entity, .. } => strip_doxygen_comment_markers(&entity.get_comment().unwrap_or_default()).into(),
+			Self::Clang { entity, gen_env, .. } => {
+				// Process `@overload` and `@copybrief` directives if possible by copying the corresponding doccomment
+				let mut out = entity.doc_comment();
+				let line = self.file_line_name().location.as_file().map_or(0, |(_, line)| line);
+				const OVERLOAD: &str = "@overload";
+				if let Some(idx) = out.find(OVERLOAD) {
+					let rep = if let Some(copy) = gen_env.get_func_comment(line, self.cpp_name(CppNameStyle::Reference).as_ref()) {
+						Owned(format!("{copy}\n\n## Overloaded parameters\n"))
+					} else {
+						"This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.".into()
+					};
+					out.to_mut().replace_range(idx..idx + OVERLOAD.len(), &rep);
+				}
+				static COPY_BRIEF: LazyLock<Regex> = LazyLock::new(|| Regex::new(r"@copybrief\s+(\w+)").unwrap());
+				out.to_mut().replace_in_place_regex_cb(&COPY_BRIEF, |comment, caps| {
+					let copy_name = caps.get(1).map(|(s, e)| &comment[s..e]).expect("Impossible");
+					let mut copy_full_name = self.cpp_namespace().into_owned();
+					copy_full_name.extend_sep("::", copy_name);
+					Some(gen_env.get_func_comment(line, &copy_full_name).unwrap_or("").into())
+				});
+				out
+			}
 			Self::Desc(desc) => desc.doc_comment.as_ref().into(),
 		}
 	}
 
-	fn cpp_namespace(&self) -> Cow<str> {
+	fn cpp_namespace(&self) -> Cow<'_, str> {
 		match self {
 			&Self::Clang { entity, .. } => DefaultElement::cpp_namespace(entity).into(),
 			Self::Desc(desc) => self.kind().map_borrowed(|kind| match kind {
@@ -712,7 +699,7 @@ impl Element for Func<'_, '_> {
 		}
 	}
 
-	fn cpp_name(&self, style: CppNameStyle) -> Cow<str> {
+	fn cpp_name(&self, style: CppNameStyle) -> Cow<'_, str> {
 		let decl_name = match self {
 			&Self::Clang { entity, gen_env, .. } => {
 				if matches!(entity.get_kind(), EntityKind::ConversionFunction) {
