@@ -11,23 +11,16 @@ impl RustElement for Field<'_, '_> {
 		SupportedModule::Core
 	}
 
-	fn rust_name(&self, style: NameStyle) -> Cow<str> {
+	fn rust_name(&self, style: NameStyle) -> Cow<'_, str> {
 		self.rust_leafname(style.turbo_fish_style())
 	}
 
-	fn rust_leafname(&self, _fish_style: FishStyle) -> Cow<str> {
+	fn rust_leafname(&self, _fish_style: FishStyle) -> Cow<'_, str> {
 		match self {
 			Self::Clang { .. } => DefaultRustNativeElement::rust_leafname(self).map_borrowed(|s| s.cpp_name_to_rust_fn_case()),
 			Self::Desc(desc) => reserved_rename(desc.cpp_fullname.localname().cpp_name_to_rust_fn_case()),
 		}
 	}
-
-	fn rendered_doc_comment(&self, comment_marker: &str, opencv_version: &str) -> String {
-		match self {
-			&Field::Clang { entity, .. } => DefaultRustNativeElement::rendered_doc_comment(entity, comment_marker, opencv_version),
-			Field::Desc(_) => "".to_string(),
-		}
-	}
 }
 
 #[derive(Debug)]
