@@ -1,10 +1,9 @@
 use std::borrow::Cow;
 use std::collections::HashMap;
-
-use once_cell::sync::Lazy;
+use std::sync::LazyLock;
 
 use super::class::ClassExt;
-use super::element::{DefaultRustNativeElement, RustElement};
+use super::element::RustElement;
 use super::type_ref::TypeRefExt;
 use super::RustNativeGeneratedElement;
 use crate::class::ClassDesc;
@@ -21,11 +20,11 @@ impl RustElement for SmartPtr<'_, '_> {
 	}
 
 	// fixme, we shouldn't override the rust_module_reference and rely on rust_module to provide the correct module
-	fn rust_module_reference(&self) -> Cow<str> {
+	fn rust_module_reference(&self) -> Cow<'_, str> {
 		"core".into()
 	}
 
-	fn rust_name(&self, style: NameStyle) -> Cow<str> {
+	fn rust_name(&self, style: NameStyle) -> Cow<'_, str> {
 		let decl_name = self.rust_leafname(style.turbo_fish_style());
 		match style {
 			NameStyle::Declaration => decl_name,
@@ -37,7 +36,7 @@ impl RustElement for SmartPtr<'_, '_> {
 		}
 	}
 
-	fn rust_leafname(&self, fish_style: FishStyle) -> Cow<str> {
+	fn rust_leafname(&self, fish_style: FishStyle) -> Cow<'_, str> {
 		format!(
 			"Ptr{fish}<{typ}>",
 			fish = fish_style.rust_qual(),
@@ -45,13 +44,6 @@ impl RustElement for SmartPtr<'_, '_> {
 		)
 		.into()
 	}
-
-	fn rendered_doc_comment(&self, comment_marker: &str, opencv_version: &str) -> String {
-		match self {
-			&Self::Clang { entity, .. } => DefaultRustNativeElement::rendered_doc_comment(entity, comment_marker, opencv_version),
-			Self::Desc(_) => "".to_string(),
-		}
-	}
 }
 
 impl RustNativeGeneratedElement for SmartPtr<'_, '_> {
@@ -60,19 +52,20 @@ impl RustNativeGeneratedElement for SmartPtr<'_, '_> {
 	}
 
 	fn gen_rust(&self, _opencv_version: &str) -> String {
-		static TPL: Lazy<CompiledInterpolation> = Lazy::new(|| include_str!("tpl/smart_ptr/rust.tpl.rs").compile_interpolation());
+		static TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/smart_ptr/rust.tpl.rs").compile_interpolation());
 
-		static TRAIT_RAW_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/smart_ptr/trait_raw.tpl.rs").compile_interpolation());
+		static TRAIT_RAW_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/smart_ptr/trait_raw.tpl.rs").compile_interpolation());
 
-		static BASE_CAST_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/smart_ptr/base_cast.tpl.rs").compile_interpolation());
+		static BASE_CAST_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/smart_ptr/base_cast.tpl.rs").compile_interpolation());
 
-		static IMPL_DEBUG_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/smart_ptr/impl_debug.rs").compile_interpolation());
+		static IMPL_DEBUG_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/smart_ptr/impl_debug.rs").compile_interpolation());
 
-		static CTOR_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/smart_ptr/ctor.tpl.rs").compile_interpolation());
+		static CTOR_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/smart_ptr/ctor.tpl.rs").compile_interpolation());
 
 		let rust_localalias = self.rust_localalias();
 		let rust_full = self.rust_name(NameStyle::ref_());
@@ -185,7 +178,8 @@ impl RustNativeGeneratedElement for SmartPtr<'_, '_> {
 	}
 
 	fn gen_cpp(&self) -> String {
-		static TPL: Lazy<CompiledInterpolation> = Lazy::new(|| include_str!("tpl/smart_ptr/cpp.tpl.cpp").compile_interpolation());
+		static TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/smart_ptr/cpp.tpl.cpp").compile_interpolation());
 
 		TPL.interpolate(&[("methods", extern_functions(self).iter().map(Func::gen_cpp).join(""))].into())
 	}
@@ -246,11 +240,11 @@ fn all_bases<'tu, 'ge>(cls: &Class<'tu, 'ge>) -> Vec<Class<'tu, 'ge>> {
 }
 
 pub trait SmartPtrExt {
-	fn rust_localalias(&self) -> Cow<str>;
+	fn rust_localalias(&self) -> Cow<'_, str>;
 }
 
 impl SmartPtrExt for SmartPtr<'_, '_> {
-	fn rust_localalias(&self) -> Cow<str> {
+	fn rust_localalias(&self) -> Cow<'_, str> {
 		/*
 		let pointee = self.pointee();
 		let pointee_alias = pointee.rust_safe_id(true);
