@@ -1,7 +1,6 @@
 use std::borrow::Cow;
 use std::collections::HashMap;
-
-use once_cell::sync::Lazy;
+use std::sync::LazyLock;
 
 use super::element::RustElement;
 use super::type_ref::{Lifetime, TypeRefExt};
@@ -18,7 +17,7 @@ impl RustElement for Vector<'_, '_> {
 		SupportedModule::Core
 	}
 
-	fn rust_name(&self, style: NameStyle) -> Cow<str> {
+	fn rust_name(&self, style: NameStyle) -> Cow<'_, str> {
 		let decl_name = self.rust_leafname(style.turbo_fish_style());
 		match style {
 			NameStyle::Declaration => decl_name,
@@ -30,7 +29,7 @@ impl RustElement for Vector<'_, '_> {
 		}
 	}
 
-	fn rust_leafname(&self, fish_style: FishStyle) -> Cow<str> {
+	fn rust_leafname(&self, fish_style: FishStyle) -> Cow<'_, str> {
 		let mut inner_typ = self.element_type();
 		if let Some(inner) = inner_typ.kind().as_pointer() {
 			// fixme, implement references properly, use VectorRef/Mut type
@@ -43,10 +42,6 @@ impl RustElement for Vector<'_, '_> {
 		)
 		.into()
 	}
-
-	fn rendered_doc_comment(&self, _comment_marker: &str, _opencv_version: &str) -> String {
-		"".to_string()
-	}
 }
 
 impl RustNativeGeneratedElement for Vector<'_, '_> {
@@ -55,25 +50,26 @@ impl RustNativeGeneratedElement for Vector<'_, '_> {
 	}
 
 	fn gen_rust(&self, opencv_version: &str) -> String {
-		static RUST_TPL: Lazy<CompiledInterpolation> = Lazy::new(|| include_str!("tpl/vector/rust.tpl.rs").compile_interpolation());
+		static RUST_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/vector/rust.tpl.rs").compile_interpolation());
 
-		static EXTERN_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/vector/rust_extern.tpl.rs").compile_interpolation());
+		static EXTERN_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/vector/rust_extern.tpl.rs").compile_interpolation());
 
-		static COPY_NON_BOOL_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/vector/rust_copy_non_bool.tpl.rs").compile_interpolation());
+		static COPY_NON_BOOL_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/vector/rust_copy_non_bool.tpl.rs").compile_interpolation());
 
-		static NON_COPY_OR_BOOL_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/vector/rust_non_copy_or_bool.tpl.rs").compile_interpolation());
+		static NON_COPY_OR_BOOL_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/vector/rust_non_copy_or_bool.tpl.rs").compile_interpolation());
 
-		static BOXED_REF_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/vector/rust_boxed_ref.tpl.rs").compile_interpolation());
+		static BOXED_REF_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/vector/rust_boxed_ref.tpl.rs").compile_interpolation());
 
-		static INPUT_ARRAY_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/vector/rust_input_array.tpl.rs").compile_interpolation());
+		static INPUT_ARRAY_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/vector/rust_input_array.tpl.rs").compile_interpolation());
 
-		static OUTPUT_ARRAY_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/vector/rust_output_array.tpl.rs").compile_interpolation());
+		static OUTPUT_ARRAY_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/vector/rust_output_array.tpl.rs").compile_interpolation());
 
 		let vec_type_ref = self.type_ref();
 		if vec_type_ref.constness().is_const() {
@@ -191,7 +187,7 @@ impl RustNativeGeneratedElement for Vector<'_, '_> {
 					);
 					EXTERN_TPL.interpolate_into(&mut impls, &inter_vars);
 					if is_data_type_or_vec_of_data_type_opencv_4 || is_data_type_or_vec_of_data_type_opencv_5 {
-						inter_vars.insert("rust_full", format!("BoxedRef<'_, {}>", rust_localalias).into());
+						inter_vars.insert("rust_full", format!("BoxedRef<'_, {rust_localalias}>").into());
 						INPUT_ARRAY_TPL.interpolate_into(&mut impls, &inter_vars);
 					}
 				}
@@ -224,8 +220,8 @@ impl RustNativeGeneratedElement for Vector<'_, '_> {
 	}
 
 	fn gen_cpp(&self) -> String {
-		static COMMON_TPL: Lazy<CompiledInterpolation> =
-			Lazy::new(|| include_str!("tpl/vector/cpp.tpl.cpp").compile_interpolation());
+		static COMMON_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/vector/cpp.tpl.cpp").compile_interpolation());
 
 		if self.type_ref().constness().is_const() {
 			// todo we should generate smth like VectorRef in this case
@@ -308,7 +304,7 @@ fn is_data_type_or_vec_of_data_type(type_ref: &TypeRef, for_opencv_5: bool) -> b
 
 pub trait VectorExt {
 	fn rust_element_module(&self) -> SupportedModule;
-	fn rust_localalias(&self) -> Cow<str>;
+	fn rust_localalias(&self) -> Cow<'_, str>;
 }
 
 impl VectorExt for Vector<'_, '_> {
@@ -316,7 +312,7 @@ impl VectorExt for Vector<'_, '_> {
 		self.element_type().rust_module()
 	}
 
-	fn rust_localalias(&self) -> Cow<str> {
+	fn rust_localalias(&self) -> Cow<'_, str> {
 		format!("VectorOf{typ}", typ = self.element_type().rust_safe_id(true)).into()
 	}
 }
